@@ -34,7 +34,7 @@ struct pth_event_st {
     int ev_type;
     int ev_goal;
     union {
-        struct { int fd; int was_blocking; }                      FD;
+        struct { int fd; }                                        FD;
         struct { int *n; int nfd; fd_set *rfds, *wfds, *efds; }   SELECT;
         struct { sigset_t *sigs; int *sig; }                      SIGS;
         struct { pth_time_t tv; }                                 TIME;
@@ -111,10 +111,6 @@ pth_event_t pth_event(unsigned long spec, ...)
                                     PTH_UNTIL_FD_WRITEABLE|\
                                     PTH_UNTIL_FD_EXCEPTION));
         ev->ev_args.FD.fd = fd;
-        if (pth_nonblocking(fd))
-            ev->ev_args.FD.was_blocking = FALSE;
-        else
-            ev->ev_args.FD.was_blocking = TRUE;
     }
     else if (spec & PTH_EVENT_SELECT) {
         /* filedescriptor set select event */
