@@ -155,8 +155,8 @@ int pth_select_ev(int nfd, fd_set *rfds, fd_set *wfds,
         }
         else {
             /* larger delays have to use the scheduler */
-            ev = pth_event(PTH_EVENT_TIME|PTH_MODE_STATIC, 
-                           &ev_key_timeout, *timeout);
+            ev = pth_event(PTH_EVENT_TIME|PTH_MODE_STATIC, &ev_key_timeout, 
+                           pth_timeout(timeout->tv_sec, timeout->tv_usec));
             if (ev_extra != NULL)
                 pth_event_concat(ev, ev_extra, NULL);
             pth_wait(ev);
@@ -210,8 +210,8 @@ int pth_select_ev(int nfd, fd_set *rfds, fd_set *wfds,
                                &ev_key_select, &rc, nfd, rfds, wfds, wfds);
     ev_timeout = NULL;
     if (timeout != NULL) {
-        ev_timeout = pth_event(PTH_EVENT_TIME|PTH_MODE_STATIC, 
-                               &ev_key_timeout, *timeout);
+        ev_timeout = pth_event(PTH_EVENT_TIME|PTH_MODE_STATIC, &ev_key_timeout, 
+                               pth_timeout(timeout->tv_sec, timeout->tv_usec));
         pth_event_concat(ev, ev_timeout, NULL);
     }
     if (ev_extra != NULL)
