@@ -124,18 +124,21 @@ int pth_mutex_release(pth_mutex_t *mutex)
     return TRUE;
 }
 
-intern int pth_mutex_releaseall(pth_t thread)
+intern void pth_mutex_releaseall(pth_t thread)
 {
-    pth_ringnode_t *rn;
+    pth_ringnode_t *rn, *rnf;
 
     if (thread == NULL)
-        return_errno(FALSE, EINVAL);
+        return;
     /* iterate over all mutexes of thread */
-    for (rn = pth_ring_first(&(thread->mutexring)); rn != NULL;
-         rn = pth_ring_next(&(thread->mutexring), rn)          )
-        if (!pth_mutex_release((pth_mutex_t *)rn))
-            return FALSE;
-    return TRUE;
+    rn = rnf = pth_ring_first(&(thread->mutexring)); 
+    while (rn != NULL) {
+        pth_mutex_release((pth_mutex_t *)rn);
+        rn = pth_ring_next(&(thread->mutexring), rn);
+        if (rn == rnf)
+            break;
+    }
+    return;
 }
 
 /*
