@@ -1052,6 +1052,18 @@ ssize_t _pthread_write(int fd, const void *buf, size_t nbytes)
     return pth_write(fd, buf, nbytes);
 }
 
+ssize_t _pthread_readv(int fd, const struct iovec *iovec, int iocnt)
+{
+    pthread_initialize();
+    return pth_readv(fd, iovec, iocnt);
+}
+
+ssize_t _pthread_writev(int fd, const struct iovec *iovec, int iocnt)
+{
+    pthread_initialize();
+    return pth_writev(fd, iovec, iocnt);
+}
+
 ssize_t _pthread_pread(int fd, void *buf, size_t nbytes, off_t offset)
 {
     pthread_initialize();
