@@ -53,6 +53,7 @@ int main(int argc, char *argv[])
     pth_t t_ticker;
     pth_attr_t t_attr;
     fd_set rfds;
+    char c;
     int n;
 
     pth_init();
@@ -83,8 +84,8 @@ int main(int argc, char *argv[])
             continue;
         }
         fprintf(stderr, "main: select returned %d\n", n);
-        while ((n = fgetc(stdin)) != EOF)
-            fprintf(stderr, "main: read stdin '%c'\n", n);
+        while (pth_read(STDIN_FILENO, &c, 1) > 0)
+            fprintf(stderr, "main: read stdin '%c'\n", c);
     }
 
     pth_event_free(evt, PTH_FREE_THIS);
